@@ -94,6 +94,31 @@ void Config::setDeviceOrientation(QOrientationReading::Orientation orientation)
     }
 }
 
+bool Config::getAutoRotate() const
+{
+    const auto outputs = m_data->outputs();
+    return std::all_of(outputs.cbegin(), outputs.cend(),
+        [this](KScreen::OutputPtr output) {
+            if (output->type() != KScreen::Output::Type::Panel) {
+                return true;
+            }
+            return m_control->getAutoRotate(output);
+        });
+}
+
+void Config::setAutoRotate(bool value)
+{
+    for (KScreen::OutputPtr &output : m_data->outputs()) {
+        if (output->type() != KScreen::Output::Type::Panel) {
+            continue;
+        }
+        if (m_control->getAutoRotate(output) != value) {
+            m_control->setAutoRotate(output, value);
+        }
+    }
+    m_control->writeFile();
+}
+
 bool Config::fileExists() const
 {
     return (QFile::exists(configsDirPath() % id()) || QFile::exists(configsDirPath() % s_fixedConfigFileName));
@@ -229,7 +254,7 @@ bool Config::writeFile(const QString &filePath)
         info[QStringLiteral("primary")] = output->isPrimary();
         info[QStringLiteral("enabled")] = output->isEnabled();
 
-        auto setOutputConfigInfo = [this, &info](const KScreen::OutputPtr &out) {
+        auto setOutputConfigInfo = [&info](const KScreen::OutputPtr &out) {
             if (!out) {
                 return;
             }
@@ -268,7 +293,7 @@ void Config::log()
         return;
     }
     const auto outputs = m_data->outputs();
-    for (const auto o : outputs) {
+    for (const auto &o : outputs) {
         if (o->isConnected()) {
             qCDebug(KSCREEN_KDED) << o;
         }
